---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Before you proceed**
Always make sure that you are running the latest version of nd2k.
```
nd2k -v
```

**Describe the bug**
A clear and concise description of what the bug is, as well as what input files were used when you came across the bug.

**Additional context**
Add any other context about the problem here. Output logs or screenshots if it makes sense.
